@@ -29,6 +29,8 @@ except ImportError:
     direction = "output"
     device = "cpu"
 
+fqdn = socket.getfqdn()
+
 
 def get_host_type():
     """Get type of current container
@@ -37,25 +39,27 @@ def get_host_type():
     """
     if not os.path.exists("/data/"):
         return None
-    fqdn = socket.getfqdn()
     if os.getenv("RLAUNCH_WORKER") or os.getenv("rrun_executor_uri"):
         return "WORKER"
-    mapping = {
-        "brw": "WORKSPACE",
-        "brc": "VM",
-        "vm2": "VM2",
-    }
+    mapping = {"brw": "WORKSPACE", "brc": "VM", "vm2": "VM2", "ws2": "WS2"}
+    # fqdn = socket.getfqdn()
     if "brainpp" not in fqdn:
         return None
-    try:
-        type_ = fqdn.split(".")[2]
-        return mapping.get(type_)
-    except IndexError:
-        return None
+    type_ = fqdn.split(".")[2]
+    assert type_ in mapping
+    return mapping[type_]
     """Consider isfile("/usr/local/bin/rlaunch") """
 
 
 host_type = get_host_type()
+site = host_type and fqdn.split(".")[3]
+
+if site:
+    OSS_ENDPOINT = "http://oss.i.brainpp.cn"
+else:
+    OSS_ENDPOINT = "http://oss-internal.hh-b.brainpp.cn"
+
+os.environ["OSS_ENDPOINT"] = os.environ.get("OSS_ENDPOINT", OSS_ENDPOINT)
 
 if __name__ == "__main__":
     pass
