@@ -236,5 +236,44 @@ class rrun_manage:
         return runner_ids
 
 
+def tar_files(dic, tarpath):
+    """
+    dic {name: smart path}
+    """
+    import io
+    import tqdm
+    import tarfile
+    from threading import Lock
+    from megfile import smart_open
+
+    if isinstance(dic, (list, tuple)):
+        dic = {os.path.basename(path): path for path in dic}
+    keys = sorted(dic)
+    iterr = iter(tqdm.tqdm(keys))
+
+    write_lock = Lock()
+
+    with smart_open(tarpath, "wb") as f:
+        with tarfile.open(fileobj=f, mode="w") as tar:
+
+            def func(key_path):
+                key, path = key_path
+                byte = smart_open(path, "rb").read()
+                info = tarfile.TarInfo(key)
+                info.size = len(byte)
+                byte_io = io.BytesIO(initial_bytes=byte)
+                with write_lock:
+                    tar.addfile(info, byte_io)
+                    next(iterr)
+
+            boxx.mapmt(func, dic.items(), pool=16)
+    print("Save to:", tarpath)
+
+    def test():
+        paths = ["s3://yl-share/tmp/a.jpg", "s3://yl-share/tmp/aa.jpg"]
+        tarpath = "s3://yl-share/tmp/test.tar"
+        tar_files(paths, tarpath)
+
+
 if __name__ == "__main__":
     pass
